﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;

namespace olymp2015school
{
    class TriangleTests
    {
        static void Main(string[] args)
        {
            if (args.Length == 1)
                (new Tests(int.Parse(args[0]))).Run();
            else
            {
                (new Tests()).Run();
            }
        }

        public class Tests
        {
            private struct Data
            {
                public readonly int N;
                public readonly int K;
                public const int MinN = 3;
                public const int MaxN = 1000000000;
                public const int MinK = 0;

                public Data(int n, int k)
                {
                    N = n;
                    K = k;
                }

                private bool Equals(Data other)
                {
                    return N == other.N && K == other.K;
                }

                public override bool Equals(object obj)
                {
                    if (ReferenceEquals(null, obj)) return false;
                    return obj is Data && Equals((Data)obj);
                }

                public override int GetHashCode()
                {
                    unchecked
                    {
                        return (N * 397) ^ K;
                    }
                }
            }

            #region Fields
            private readonly StreamWriter _writer;
            private const string FileName = "TRIANGLE.IN";
            private int _tests = 1000;
            #endregion

            #region Ctor
            public Tests()
            {
                _writer = new StreamWriter(new FileStream(FileName, FileMode.Create));
            }
            public Tests(int tests)
            {
                _writer = new StreamWriter(new FileStream(FileName, FileMode.Create));
                _tests = tests;
            }
            #endregion

            #region Methods

            public void Run()
            {

                var generatedData = GenerateTests();
                _writer.WriteLine(generatedData.Length.ToString());
                PrintTest(generatedData);
                _writer.Close();
            }

            private void PrintTest(Data data)
            {
                _writer.WriteLine("{0} {1}", data.N, data.K);
            }

            private void PrintTest(IEnumerable<Data> data)
            {
                foreach (var item in data)
                {
                    PrintTest(item);
                }
            }

            private Data[] GenerateTests()
            {
                Random random = new Random(42);
                var defaultData = GetDefaultData();
                var minMaxData = GetMinMaxData();
                var firstData = new Data[defaultData.Length + minMaxData.Length];
                defaultData.CopyTo(firstData, 0);
                minMaxData.CopyTo(firstData, defaultData.Length);
                var generatedData = new HashSet<Data>(firstData);

                while (generatedData.Count < _tests)
                {
                    for (int n = 10; n <= Data.MaxN; n *= 10)
                    {
						for (int k = 10; k <= n; k *= 10)
                        {
                            int N = random.Next(Data.MinN, n);
                            int K = -1;
							int a;
							int b;
							int att = 0;
							bool ok = false;
                            do
                            {
								att++;
								if (att == 100)
								{
									break;
								}
                                K = random.Next(Data.MinK, Math.Min(N, k) - 1);
								a = (N - K) / 3;
								b = a + K;
								ok = (N - K) % 3 == 0 && (a + a > b) && (a + b > a);
                            } while (!ok);
							if (ok)
							{
								generatedData.Add(new Data(N, K));
							}
							else
							{
								k /= 10;						
							}
						
                            if (generatedData.Count == _tests)
                                return generatedData.ToArray();
                        }
                    }
                }

                return generatedData.ToArray();
            }

            private Data[] GetDefaultData()
            {
                return new[]
                {
                    new Data(23,2),
                    new Data(18,0)
                };
            }

            private Data[] GetMinMaxData()
            {
                return new[]
                {
					new Data(3, 0),
					new Data(1000000000, 1),
					new Data(1000000000, 249999997)
                    //new Data(Data.MinN, Data.MinK),
                    //new Data(Data.MinN, Data.MinN-1), minN и maxK сочетание проверять бесполезно, так как maxK = N-1, а 1%3!=0
                    //new Data(Data.MaxN, Data.MinK+1),
                    //new Data(Data.MaxN, Data.MaxN-3) //MaxK = N-1
                };
            }
            #endregion
        }
    }
}
