import java.io.File;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.*;

/**
 * @author Oleg Arshinsky (velet5@ya.ru)
 */
@SuppressWarnings("ResultOfMethodCallIgnored")
public class Blocks_TestGenerator {

    static PrintWriter INPUT;
    static PrintWriter OUTPUT;

    static class Test {

        public Test(final List<Integer> numbers) {
            length = numbers.size();
            question = genQuestion(numbers);
            answer = genAnswer(numbers);
        }

        private String genQuestion(List<Integer> numbers) {
            final StringBuilder sb = new StringBuilder();
            for (Integer number : numbers) {
                sb.append(number);
                sb.append(' ');
            }
            sb.deleteCharAt(sb.length() - 1);
            return sb.toString();
        }

        private String genAnswer(final List<Integer> numbers) {
            Integer prev = numbers.get(0);
            int count = 0;
            int total = 0;
            final StringBuilder sb = new StringBuilder();

            for (Integer number : numbers) {
                if (number.equals(prev)){
                    count += 1;
                } else {
                    total += 1;
                    sb.append('[');
                    sb.append(prev);
                    sb.append(' ');
                    sb.append(count);
                    sb.append(']');
                    sb.append(' ');
                    count = 1;
                }
                prev = number;
            }

            total += 1;
            sb.append('[');
            sb.append(prev);
            sb.append(' ');
            sb.append(count);
            sb.append(']');

            return Integer.valueOf(total).toString() + ' ' + sb.toString();
        }

        public final int length;
        public final String question;
        public final String answer;
    }

    static {
        final File input = new File("BLOCKS.IN");
        final File output = new File("BLOCKS.OUT");

        try {
            input.createNewFile();
            output.createNewFile();
            INPUT  = new PrintWriter(input);
            OUTPUT = new PrintWriter(output);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    static void same(final int len, final int num) {
        INPUT.write("" + len);
        INPUT.write("\r\n");
        for (int i = 0; i < len; i++) {
            INPUT.write("" + num);
            INPUT.write(i == len-1 ? "\r\n" : " ");
        }
        OUTPUT.write("1 [" + num + " " + len + "]\r\n");
    }

    static void ascending(final int len, final int from) {
        INPUT.write("" + len);
        INPUT.write("\r\n");
        OUTPUT.write("" + len + " ");
        for (int i = 0; i <len; i++) {
            INPUT.write("" + (from + i));
            INPUT.write(i == len-1 ? "\r\n" : " ");
            OUTPUT.write("[" + (from + i) + " 1]");
            OUTPUT.write(i == len - 1 ? "\r\n" : " ");
        }
    }

    static void descending(final int len, final int from) {
        INPUT.write("" + len);
        INPUT.write("\r\n");
        OUTPUT.write("" + len + " ");
        for (int i = 0; i <len; i++) {
            INPUT.write("" + (from - i));
            INPUT.write(i == len-1 ? "\r\n" : " ");
            OUTPUT.write("[" + (from - i) + " 1]");
            OUTPUT.write(i == len-1 ? "\r\n" : " ");
        }
    }

    static void pairs(final int len, final int from) {
        INPUT.write("" + len);
        INPUT.write("\r\n");
        OUTPUT.write("" + len/2 + " ");
        for (int i = 0; i <len/2; i++) {
            INPUT.write("" + (from + i));
            INPUT.write(" " + (from + i));
            INPUT.write(i == len/2-1? "\r\n" : " ");
            OUTPUT.write("[" + (from + i) + " 2]");
            OUTPUT.write(i == len/2-1 ? "\r\n" : " ");
        }
    }

    static List<Integer> random(final int len, final int bound) {
        final Random random = new Random();
        final ArrayList<Integer> list = new ArrayList<Integer>();
        for (int i = 0; i < len; i++) {
            list.add(random.nextInt(bound * 2) - bound);
        }
        return list;
    }

    static List<Integer> one(final int num) {
        return Collections.singletonList(num);
    }

    static void writeTest(final Test test) {
        INPUT.write("" + test.length);
        INPUT.write("\r\n");
        INPUT.write(test.question);
        INPUT.write("\r\n");
        OUTPUT.write(test.answer);
        OUTPUT.write("\r\n");
    }

    public static void main(String[] args) {
        INPUT.write("9016\n"); // number of tests

        writeTest(new Test(Arrays.asList(1, 1, 2, 3, 3, 3, 2, 1, 1)));
        writeTest(new Test(one(1)));
        writeTest(new Test(one(10)));
        writeTest(new Test(one(0)));
        writeTest(new Test(one(-1)));
        same(1000000, 1);
        writeTest(new Test(one(-1000000000)));
        ascending(100, -1000000000);
        descending(100, 1000000000);
        same(100, 0);
        same(100, 1);
        same(100, -1);
        same(100, 1000000000);
        same(100, -999999999);
        same(100, -999999999);
        pairs(100, -999999999);

        for (int i = 0; i < 50; i++) {
            for (int j = 0; j < 100; j++) {
                writeTest(new Test(random(10 + i, i + 10)));
            }
        }

        for (int i = 0; i < 40; i++) {
            for (int j = 0; j < 100; j++) {
                writeTest(new Test(random(20 + i, i + 10)));
            }
        }

        INPUT.close();
        OUTPUT.close();
    }

}
