import java.io.InputStreamReader;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.io.BufferedWriter;
import java.util.InputMismatchException;
import java.io.BufferedReader;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.FileInputStream;
import java.io.Writer;
import java.util.StringTokenizer;
import java.util.LinkedList;
import java.io.InputStream;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 * @author Andrey Rechitsky (arechitsky@gmail.com)
 */
public class Blocks_ar {
    public static void main(String[] args) {
        InputStream inputStream;
        try {
            inputStream = new FileInputStream("BLOCKS.IN");
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        OutputStream outputStream = System.out;
        FastScanner in = new FastScanner(inputStream);
        FastPrinter out = new FastPrinter(outputStream);
        TaskB solver = new TaskB();
        int testCount = Integer.parseInt(in.next());
        for (int i = 1; i <= testCount; i++)
            solver.solve(i, in, out);
        out.close();
    }
}

class TaskB {
    public void solve(int testNumber, FastScanner in, FastPrinter out) {
        int n = in.nextInt();
        if (n < 1 || n > 1000000)
            throw new InputMismatchException(String.format("test #%d: n=%d is out of range [1, 10e6]", testNumber, n));
        int[] a = in.nextIntArray(n);

        LinkedList<Integer> lengths = new LinkedList<Integer>(); // lengths of all blocks
        int length = 1; // length of current block
        for (int i = 1; i < n; i++) {
            if (a[i - 1] == a[i]) length++; // same as previous, increase length
            else {
                lengths.add(length); // write length
                length = 1; // start new block
            }
        }
        lengths.add(length); // write last block

        out.print(lengths.size()); // print counts of blocks
        int pos = 0; // position of first element of current block
        for (int l : lengths) {
            //out.print(" [%d %d]", a[pos], l); // too slow; 1.25 seconds with this code
            out.print(" [");
            out.print(a[pos]);
            out.print(' ');
            out.print(l);
            out.print(']');
            pos += l; // move position to next block
        }
        out.printLine();
    }
}

class FastScanner {

    private BufferedReader reader;
    private StringTokenizer st;

    public FastScanner(InputStream stream) {
        this.reader = new BufferedReader(new InputStreamReader(stream));
        this.st = new StringTokenizer("");
    }

    public int nextInt() {
        return Integer.parseInt(next());
    }

    public String next() {
        while (!st.hasMoreTokens()) {
            st = new StringTokenizer(readLine());
        }
        return st.nextToken();
    }

    private String readLine() {
        try {
            String line = reader.readLine();
            if (line == null) throw new InputMismatchException();
            return line;
        } catch (IOException e) {
            throw new InputMismatchException();
        }
    }

    public int[] nextIntArray(int size) {
        int[] array = new int[size];
        for (int i = 0; i < size; i++)
            array[i] = nextInt();
        return array;
    }

}

class FastPrinter {
    private final PrintWriter writer;

    public FastPrinter(OutputStream outputStream) {
        writer = new PrintWriter(new BufferedWriter(new OutputStreamWriter(outputStream)));
    }

    public void close() {
        writer.close();
    }

    public void printLine() {
        writer.println();
    }

    public void print(long i) {
        writer.print(i);
    }

    public void print(char c) {
        writer.print(c);
    }

    public void print(String s) {
        writer.print(s);
    }

}

