import java.io.*;
import java.util.InputMismatchException;
import java.util.LinkedList;
import java.util.Random;
import java.util.StringTokenizer;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 *
 * @author Andrey Rechitsky (arechitsky@gmail.com)
 */
public class Main {
    public static void main(String[] args) {
        OutputStream generatorOutputStream;
        try {
            generatorOutputStream = new FileOutputStream("WORDS.IN");
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        FastPrinter generatorOut = new FastPrinter(generatorOutputStream);
        int maxLen = 1000;
        int step = 100;
        int randomCount = 100;
        long seed = 123123;
        if (args.length >= 1) maxLen = Integer.parseInt(args[0]);
        if (args.length >= 2) step = Integer.parseInt(args[1]);
        if (args.length >= 3) randomCount = Integer.parseInt(args[2]);
        if (args.length >= 4) seed = Long.parseLong(args[3]);
        InputGenerator generator = new InputGenerator();
        generator.generate(maxLen, step, randomCount, seed, generatorOut);
        generatorOut.close();

        InputStream solverInputStream;
        try {
            solverInputStream = new FileInputStream("WORDS.IN");
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        OutputStream solverOutputStream;
        try {
            solverOutputStream = new FileOutputStream("WORDS.OUT");
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
        FastScanner in = new FastScanner(solverInputStream);
        FastPrinter out = new FastPrinter(solverOutputStream);
        Words solver = new Words();
        int testCount = Integer.parseInt(in.next());
        for (int i = 1; i <= testCount; i++)
            solver.solve(i, in, out);
        out.close();
    }
}

class InputGenerator {
    Random rnd;

    public void generate(int maxLen, int step, int randomCount, long seed, FastPrinter out) {
        rnd = new Random(seed);

        LinkedList<String> tests = new LinkedList<String>();
        tests.add(sample1());
        tests.add(sample2());
        for (int len = step; len <= maxLen; len += step) {
            tests.add(maxWords(len, false));
        }

        for (int i = 0; i < randomCount; i++) {
            int len = rnd.nextInt(maxLen) + 1;
            double spaceRate = 0.1 + 0.5 * rnd.nextDouble();
            tests.add(random(len, spaceRate));
        }

        out.printLine(tests.size());
        for (String test : tests) {
            out.printLine(test);
        }
    }

    String sample1() {
        return "Very  interesting   problem";
    }

    String sample2() {
        return "  Test  ";
    }

    String maxWords(int length, boolean random) {
        StringBuilder sb = new StringBuilder();
        for (int i = 0; i < length / 2; i++) {
            sb.append(random ? randomLetter() : 'A');
            sb.append(' ');
        }
        if (length % 2 == 1) sb.append(random ? randomLetter() : 'A');
        return sb.toString();
    }

    String random(int length, double spaceRate) {
        StringBuilder sb = new StringBuilder();
        for (int i = 0; i < length; i++) {
            sb.append(rnd.nextDouble() < spaceRate ? ' ' : randomLetter());
        }
        return sb.toString();
    }

    char randomLetter() {
        char base = rnd.nextBoolean() ? 'a' : 'A';
        return (char) (base + rnd.nextInt(26));
    }

}

class Words {
    public void solve(int testNumber, FastScanner in, FastPrinter out) {
        String[] words = in.nextLine().split(" ");
        StringBuilder spaces = new StringBuilder();

        out.printLine("Case %d:", testNumber);
        for (String word : words) {
            if (word.length() == 0) continue;
            out.print(spaces.toString());
            out.printLine(word);
            for (int i = 0; i < word.length(); i++) {
                spaces.append(' ');
            }
        }
    }
}

class FastScanner {

    private BufferedReader reader;
    private StringTokenizer st;

    public FastScanner(InputStream stream) {
        this.reader = new BufferedReader(new InputStreamReader(stream));
        this.st = new StringTokenizer("");
    }

    public String next() {
        while (!st.hasMoreTokens()) {
            st = new StringTokenizer(readLine());
        }
        return st.nextToken();
    }

    public String nextLine() {
        st = new StringTokenizer("");
        return readLine();
    }

    private String readLine() {
        String line = tryReadLine();
        if (line == null) throw new InputMismatchException();
        return line;
    }

    private String tryReadLine() {
        try {
            return reader.readLine();
        } catch (IOException e) {
            throw new InputMismatchException();
        }
    }

}

class FastPrinter {
    private final PrintWriter writer;

    public FastPrinter(OutputStream outputStream) {
        writer = new PrintWriter(new BufferedWriter(new OutputStreamWriter(outputStream)));
    }

    public void close() {
        writer.close();
    }

    public void printLine(long i) {
        writer.println(i);
    }

    public void printLine(String s) {
        writer.println(s);
    }

    public void printLine(String format, Object... args) {
        printLine(String.format(format, args));
    }

    public void print(String s) {
        writer.print(s);
    }

}

